# OpenLeap

## Table of contents
* [General Info](#general-info)
* [Technologies](#technologies)
* [Setup](#setup)

## General Info
OpenLeap is an open source project that allows you to add hand gesture control to your Python projects. 

## Technologies

Project was created with technologies:

* Python
* OpenCV
* MediaPipe
* SciKit Learn

## Setup
```
$ pip install openleap
```
